about summary refs log tree commit diff
path: root/sysdeps/x86/tst-ifunc-isa.h
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/x86/tst-ifunc-isa.h')
-rw-r--r--sysdeps/x86/tst-ifunc-isa.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/sysdeps/x86/tst-ifunc-isa.h b/sysdeps/x86/tst-ifunc-isa.h
index 6d906966a7..85616e29ad 100644
--- a/sysdeps/x86/tst-ifunc-isa.h
+++ b/sysdeps/x86/tst-ifunc-isa.h
@@ -1,4 +1,4 @@
 /* IFUNC resolver with CPU_FEATURE_USABLE.
    Copyright (C) 2021 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -32,15 +32,15 @@ enum isa
 __attribute__ ((__optimize__ ("-fno-stack-protector")))
 get_isa (void)
 {
-  if (CPU_FEATURE_USABLE (AVX512F))
+  if (CPU_FEATURE_ACTIVE (AVX512F))
     return avx512f;
-  if (CPU_FEATURE_USABLE (AVX2))
+  if (CPU_FEATURE_ACTIVE (AVX2))
     return avx2;
-  if (CPU_FEATURE_USABLE (AVX))
+  if (CPU_FEATURE_ACTIVE (AVX))
     return avx;
-  if (CPU_FEATURE_USABLE (SSE4_2))
+  if (CPU_FEATURE_ACTIVE (SSE4_2))
     return sse4_2;
-  if (CPU_FEATURE_USABLE (SSE2))
+  if (CPU_FEATURE_ACTIVE (SSE2))
     return sse2;
   return none;
 }
@@ -1,4 +1,4 @@
-/* IFUNC resolver with CPU_FEATURE_USABLE.
+/* IFUNC resolver with CPU_FEATURE_ACTIVE.
    Copyright (C) 2021 Free Software Foundation, Inc.
    This file is part of the GNU C Library.